import os
import string
from pprint import pprint
from random import choice, randint

from numpy.random import seed
from tensorflow_core.python.framework.random_seed import set_random_seed


def load_kawa(root="./"):
    # set seeds for reproducibility
    set_random_seed(2)
    seed(1)
    data_dir = root + 'data/'
    all_lines = []
    files = os.listdir(data_dir)
    print("%i files in data folder." % len(files))
    for filename in files:
        with open(data_dir + filename) as f:
            content = f.readlines()
            all_lines.extend(content)

    all_lines = [h for h in all_lines if h[0] not in ["[", "#"]
                 ]
    len(all_lines)
    print("Loaded %i lines of data: %s." % (len(all_lines), all_lines[0]))
    return all_lines


def load_seeds(kawa=None, nb_seeds=10):
    if kawa is None:
        kawa = load_kawa()
    seeds = []
    for i in range(nb_seeds):
        plain_kawa = filter(lambda k: k != "\n", kawa)
        chosen = choice(list(plain_kawa))
        split = chosen.split(" ")
        nb_words = randint(1, len(split))
        seeds.append(" ".join(split[:nb_words]))
    return seeds


def clean_text(lines):
    """
    In dataset preparation step, we will first perform text cleaning of the data
    which includes removal of punctuations and lower casing all the words.
    """
    lines = "".join(v for v in lines if v not in string.punctuation)
    # lines = lines.encode("utf8").decode("ascii", 'ignore')
    return lines


def main():
    lines = load_kawa("../")
    clean = clean_text(lines)
    print(clean)
    print("Some seeds:")
    pprint(load_seeds(lines))


if __name__ == '__main__':
    main()
